Class: Google::Cloud::Bigtable::Admin::V2::AppProfile
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::AppProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/instance.rb
Overview
A configuration object describing how Cloud Bigtable should treat traffic from a particular end user application.
Defined Under Namespace
Classes: MultiClusterRoutingUseAny, SingleClusterRouting
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional long form description of the use case for this AppProfile.
-
#etag ⇒ ::String
Strongly validated etag for optimistic concurrency control.
-
#multi_cluster_routing_use_any ⇒ ::Google::Cloud::Bigtable::Admin::V2::AppProfile::MultiClusterRoutingUseAny
Use a multi-cluster routing policy.
-
#name ⇒ ::String
(
OutputOnly) The unique name of the app profile. -
#single_cluster_routing ⇒ ::Google::Cloud::Bigtable::Admin::V2::AppProfile::SingleClusterRouting
Use a single-cluster routing policy.
Instance Attribute Details
#description ⇒ ::String
Returns Optional long form description of the use case for this AppProfile.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 209 class AppProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Read/write requests are routed to the nearest cluster in the instance, and # will fail over to the nearest cluster that is available in the event of # transient errors or delays. Clusters in a region are considered # equidistant. Choosing this option sacrifices read-your-writes consistency # to improve availability. class MultiClusterRoutingUseAny include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Unconditionally routes all read/write requests to a specific cluster. # This option preserves read-your-writes consistency but does not improve # availability. # @!attribute [rw] cluster_id # @return [::String] # The cluster to which read/write requests should be routed. # @!attribute [rw] allow_transactional_writes # @return [::Boolean] # Whether or not `CheckAndMutateRow` and `ReadModifyWriteRow` requests are # allowed by this app profile. It is unsafe to send these requests to # the same table/row/column in multiple clusters. class SingleClusterRouting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String
Returns Strongly validated etag for optimistic concurrency control. Preserve the
value returned from GetAppProfile when calling UpdateAppProfile to
fail the request if there has been a modification in the mean time. The
update_mask of the request need not include etag for this protection
to apply.
See Wikipedia and
RFC 7232 for more
details.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 209 class AppProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Read/write requests are routed to the nearest cluster in the instance, and # will fail over to the nearest cluster that is available in the event of # transient errors or delays. Clusters in a region are considered # equidistant. Choosing this option sacrifices read-your-writes consistency # to improve availability. class MultiClusterRoutingUseAny include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Unconditionally routes all read/write requests to a specific cluster. # This option preserves read-your-writes consistency but does not improve # availability. # @!attribute [rw] cluster_id # @return [::String] # The cluster to which read/write requests should be routed. # @!attribute [rw] allow_transactional_writes # @return [::Boolean] # Whether or not `CheckAndMutateRow` and `ReadModifyWriteRow` requests are # allowed by this app profile. It is unsafe to send these requests to # the same table/row/column in multiple clusters. class SingleClusterRouting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multi_cluster_routing_use_any ⇒ ::Google::Cloud::Bigtable::Admin::V2::AppProfile::MultiClusterRoutingUseAny
Returns Use a multi-cluster routing policy.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 209 class AppProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Read/write requests are routed to the nearest cluster in the instance, and # will fail over to the nearest cluster that is available in the event of # transient errors or delays. Clusters in a region are considered # equidistant. Choosing this option sacrifices read-your-writes consistency # to improve availability. class MultiClusterRoutingUseAny include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Unconditionally routes all read/write requests to a specific cluster. # This option preserves read-your-writes consistency but does not improve # availability. # @!attribute [rw] cluster_id # @return [::String] # The cluster to which read/write requests should be routed. # @!attribute [rw] allow_transactional_writes # @return [::Boolean] # Whether or not `CheckAndMutateRow` and `ReadModifyWriteRow` requests are # allowed by this app profile. It is unsafe to send these requests to # the same table/row/column in multiple clusters. class SingleClusterRouting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns (OutputOnly)
The unique name of the app profile. Values are of the form
projects/{project}/instances/{instance}/appProfiles/[_a-zA-Z0-9][-_.a-zA-Z0-9]*.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 209 class AppProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Read/write requests are routed to the nearest cluster in the instance, and # will fail over to the nearest cluster that is available in the event of # transient errors or delays. Clusters in a region are considered # equidistant. Choosing this option sacrifices read-your-writes consistency # to improve availability. class MultiClusterRoutingUseAny include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Unconditionally routes all read/write requests to a specific cluster. # This option preserves read-your-writes consistency but does not improve # availability. # @!attribute [rw] cluster_id # @return [::String] # The cluster to which read/write requests should be routed. # @!attribute [rw] allow_transactional_writes # @return [::Boolean] # Whether or not `CheckAndMutateRow` and `ReadModifyWriteRow` requests are # allowed by this app profile. It is unsafe to send these requests to # the same table/row/column in multiple clusters. class SingleClusterRouting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#single_cluster_routing ⇒ ::Google::Cloud::Bigtable::Admin::V2::AppProfile::SingleClusterRouting
Returns Use a single-cluster routing policy.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 209 class AppProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Read/write requests are routed to the nearest cluster in the instance, and # will fail over to the nearest cluster that is available in the event of # transient errors or delays. Clusters in a region are considered # equidistant. Choosing this option sacrifices read-your-writes consistency # to improve availability. class MultiClusterRoutingUseAny include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Unconditionally routes all read/write requests to a specific cluster. # This option preserves read-your-writes consistency but does not improve # availability. # @!attribute [rw] cluster_id # @return [::String] # The cluster to which read/write requests should be routed. # @!attribute [rw] allow_transactional_writes # @return [::Boolean] # Whether or not `CheckAndMutateRow` and `ReadModifyWriteRow` requests are # allowed by this app profile. It is unsafe to send these requests to # the same table/row/column in multiple clusters. class SingleClusterRouting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |