Class: Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb
Overview
Client for the BigtableTableAdmin service.
Service for creating, configuring, and deleting Cloud Bigtable tables.
Provides access to the table schemas only, not the data stored within the tables.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the BigtableTableAdmin Client class.
Instance Method Summary collapse
-
#check_consistency(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::CheckConsistencyResponse
Checks replication consistency based on a consistency token, that is, if replication has caught up based on the conditions specified in the token and the check request.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the BigtableTableAdmin Client instance.
-
#create_backup(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Starts creating a new Cloud Bigtable Backup.
-
#create_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Creates a new table in the specified instance.
-
#create_table_from_snapshot(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a new table from the specified snapshot.
-
#delete_backup(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a pending or completed Cloud Bigtable backup.
-
#delete_snapshot(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Permanently deletes the specified snapshot.
-
#delete_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Permanently deletes a specified table and all of its data.
-
#drop_row_range(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Permanently drop/delete a row range from a specified table.
-
#generate_consistency_token(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::GenerateConsistencyTokenResponse
Generates a consistency token for a Table, which can be used in CheckConsistency to check whether mutations to the table that finished before this call started have been replicated.
-
#get_backup(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup
Gets metadata on a pending or completed Cloud Bigtable Backup.
-
#get_iam_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Iam::V1::Policy
Gets the access control policy for a Table or Backup resource.
-
#get_snapshot(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Snapshot
Gets metadata information about the specified snapshot.
-
#get_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Gets metadata information about the specified table.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new BigtableTableAdmin client object.
-
#list_backups(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Backup>
Lists Cloud Bigtable backups.
-
#list_snapshots(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Snapshot>
Lists all snapshots associated with the specified cluster.
-
#list_tables(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Table>
Lists all tables served from a specified instance.
-
#modify_column_families(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Performs a series of column family modifications on the specified table.
-
#restore_table(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Create a new table by restoring from a completed backup.
-
#set_iam_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Iam::V1::Policy
Sets the access control policy on a Table or Backup resource.
-
#snapshot_table(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a new snapshot in the specified cluster from the specified source table.
-
#test_iam_permissions(request, options = nil) {|response, operation| ... } ⇒ ::Google::Iam::V1::TestIamPermissionsResponse
Returns permissions that the caller has on the specified Table or Backup resource.
-
#update_backup(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup
Updates a pending or completed Cloud Bigtable Backup.
Methods included from Paths
#backup_path, #cluster_path, #instance_path, #snapshot_path, #table_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new BigtableTableAdmin client object.
Examples
To create a new BigtableTableAdmin client with the default configuration:
client = ::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Client.new
To create a new BigtableTableAdmin client with a custom configuration:
client = ::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Client.new do |config|
config.timeout = 10.0
end
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 199 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/bigtable/admin/v2/bigtable_table_admin_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials credentials ||= Credentials.default scope: @config.scope if credentials.is_a?(String) || credentials.is_a?(Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.endpoint = @config.endpoint end @bigtable_table_admin_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors ) end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Operations (readonly)
Get the associated client for long-running operations.
240 241 242 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 240 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the BigtableTableAdmin Client class.
See Configuration for a description of the configuration fields.
Example
To modify the configuration for all BigtableTableAdmin clients:
::Google::Cloud::Bigtable::Admin::V2::BigtableTableAdmin::Client.configure do |config|
config.timeout = 10.0
end
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Bigtable", "Admin", "V2"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const&.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_table.timeout = 300.0 default_config.rpcs.create_table_from_snapshot.timeout = 60.0 default_config.rpcs.list_tables.timeout = 60.0 default_config.rpcs.list_tables.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.get_table.timeout = 60.0 default_config.rpcs.get_table.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.delete_table.timeout = 60.0 default_config.rpcs.modify_column_families.timeout = 300.0 default_config.rpcs.drop_row_range.timeout = 3600.0 default_config.rpcs.generate_consistency_token.timeout = 60.0 default_config.rpcs.generate_consistency_token.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.check_consistency.timeout = 60.0 default_config.rpcs.check_consistency.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.snapshot_table.timeout = 60.0 default_config.rpcs.get_snapshot.timeout = 60.0 default_config.rpcs.get_snapshot.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.list_snapshots.timeout = 60.0 default_config.rpcs.list_snapshots.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.delete_snapshot.timeout = 60.0 default_config.rpcs.get_iam_policy.timeout = 60.0 default_config.rpcs.get_iam_policy.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.set_iam_policy.timeout = 60.0 default_config.rpcs..timeout = 60.0 default_config.rpcs..retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#check_consistency(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::CheckConsistencyResponse #check_consistency(name: nil, consistency_token: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::CheckConsistencyResponse
Checks replication consistency based on a consistency token, that is, if replication has caught up based on the conditions specified in the token and the check request.
898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 898 def check_consistency request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::CheckConsistencyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.check_consistency..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.check_consistency.timeout, metadata: , retry_policy: @config.rpcs.check_consistency.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :check_consistency, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the BigtableTableAdmin Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
174 175 176 177 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 174 def configure yield @config if block_given? @config end |
#create_backup(request, options = nil) ⇒ ::Gapic::Operation #create_backup(parent: nil, backup_id: nil, backup: nil) ⇒ ::Gapic::Operation
Starts creating a new Cloud Bigtable Backup. The returned backup long-running operation can be used to track creation of the backup. The metadata field type is CreateBackupMetadata. The response field type is Backup, if successful. Cancelling the returned operation will stop the creation and delete the backup.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1304 def create_backup request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::CreateBackupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_backup..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_backup.timeout, metadata: , retry_policy: @config.rpcs.create_backup.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :create_backup, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_table(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table #create_table(parent: nil, table_id: nil, table: nil, initial_splits: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Creates a new table in the specified instance. The table can be created with a full set of initial column families, specified in the request.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 299 def create_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::CreateTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_table..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_table.timeout, metadata: , retry_policy: @config.rpcs.create_table.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :create_table, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_table_from_snapshot(request, options = nil) ⇒ ::Gapic::Operation #create_table_from_snapshot(parent: nil, table_id: nil, source_snapshot: nil) ⇒ ::Gapic::Operation
Creates a new table from the specified snapshot. The target table must not exist. The snapshot and the table must be in the same instance.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 381 def create_table_from_snapshot request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::CreateTableFromSnapshotRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_table_from_snapshot..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_table_from_snapshot.timeout, metadata: , retry_policy: @config.rpcs.create_table_from_snapshot.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :create_table_from_snapshot, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_backup(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_backup(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a pending or completed Cloud Bigtable backup.
1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1516 def delete_backup request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::DeleteBackupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_backup..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_backup.timeout, metadata: , retry_policy: @config.rpcs.delete_backup.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :delete_backup, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_snapshot(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_snapshot(name: nil) ⇒ ::Google::Protobuf::Empty
Permanently deletes the specified snapshot.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1220 def delete_snapshot request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::DeleteSnapshotRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_snapshot..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_snapshot.timeout, metadata: , retry_policy: @config.rpcs.delete_snapshot.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :delete_snapshot, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_table(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_table(name: nil) ⇒ ::Google::Protobuf::Empty
Permanently deletes a specified table and all of its data.
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 604 def delete_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::DeleteTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_table..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_table.timeout, metadata: , retry_policy: @config.rpcs.delete_table.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :delete_table, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#drop_row_range(request, options = nil) ⇒ ::Google::Protobuf::Empty #drop_row_range(name: nil, row_key_prefix: nil, delete_all_data_from_table: nil) ⇒ ::Google::Protobuf::Empty
Permanently drop/delete a row range from a specified table. The request can specify whether to delete all rows in a table, or only those that match a particular prefix.
755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 755 def drop_row_range request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::DropRowRangeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.drop_row_range..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.drop_row_range.timeout, metadata: , retry_policy: @config.rpcs.drop_row_range.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :drop_row_range, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#generate_consistency_token(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::GenerateConsistencyTokenResponse #generate_consistency_token(name: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::GenerateConsistencyTokenResponse
Generates a consistency token for a Table, which can be used in CheckConsistency to check whether mutations to the table that finished before this call started have been replicated. The tokens will be available for 90 days.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 826 def generate_consistency_token request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::GenerateConsistencyTokenRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_consistency_token..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_consistency_token.timeout, metadata: , retry_policy: @config.rpcs.generate_consistency_token.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :generate_consistency_token, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_backup(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup #get_backup(name: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup
Gets metadata on a pending or completed Cloud Bigtable Backup.
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1373 def get_backup request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::GetBackupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_backup..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_backup.timeout, metadata: , retry_policy: @config.rpcs.get_backup.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :get_backup, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_iam_policy(request, options = nil) ⇒ ::Google::Iam::V1::Policy #get_iam_policy(resource: nil, options: nil) ⇒ ::Google::Iam::V1::Policy
Gets the access control policy for a Table or Backup resource. Returns an empty policy if the resource exists but does not have a policy set.
1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1805 def get_iam_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V1::GetIamPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_iam_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "resource" => request.resource } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_iam_policy.timeout, metadata: , retry_policy: @config.rpcs.get_iam_policy.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :get_iam_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_snapshot(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Snapshot #get_snapshot(name: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Snapshot
Gets metadata information about the specified snapshot.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1064 def get_snapshot request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::GetSnapshotRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_snapshot..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_snapshot.timeout, metadata: , retry_policy: @config.rpcs.get_snapshot.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :get_snapshot, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_table(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table #get_table(name: nil, view: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Gets metadata information about the specified table.
536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 536 def get_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::GetTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_table..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_table.timeout, metadata: , retry_policy: @config.rpcs.get_table.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :get_table, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_backups(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Backup> #list_backups(parent: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Backup>
Lists Cloud Bigtable backups. Returns both completed and pending backups.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1648 def list_backups request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::ListBackupsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_backups..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_backups.timeout, metadata: , retry_policy: @config.rpcs.list_backups.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :list_backups, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @bigtable_table_admin_stub, :list_backups, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_snapshots(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Snapshot> #list_snapshots(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Snapshot>
Lists all snapshots associated with the specified cluster.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1145 def list_snapshots request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::ListSnapshotsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_snapshots..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_snapshots.timeout, metadata: , retry_policy: @config.rpcs.list_snapshots.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :list_snapshots, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @bigtable_table_admin_stub, :list_snapshots, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_tables(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Table> #list_tables(parent: nil, view: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Bigtable::Admin::V2::Table>
Lists all tables served from a specified instance.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 464 def list_tables request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::ListTablesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_tables..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_tables.timeout, metadata: , retry_policy: @config.rpcs.list_tables.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :list_tables, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @bigtable_table_admin_stub, :list_tables, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#modify_column_families(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table #modify_column_families(name: nil, modifications: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Table
Performs a series of column family modifications on the specified table. Either all or none of the modifications will occur before this method returns, but data requests received prior to that point may see a table where only some modifications have taken effect.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 680 def modify_column_families request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::ModifyColumnFamiliesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.modify_column_families..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.modify_column_families.timeout, metadata: , retry_policy: @config.rpcs.modify_column_families.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :modify_column_families, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#restore_table(request, options = nil) ⇒ ::Gapic::Operation #restore_table(parent: nil, table_id: nil, backup: nil) ⇒ ::Gapic::Operation
Create a new table by restoring from a completed backup. The new table must be in the same instance as the instance containing the backup. The returned table long-running operation can be used to track the progress of the operation, and to cancel it. The metadata field type is [RestoreTableMetadata][google.bigtable.admin.RestoreTableMetadata]. The response type is Table, if successful.
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1732 def restore_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::RestoreTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.restore_table..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.restore_table.timeout, metadata: , retry_policy: @config.rpcs.restore_table.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :restore_table, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#set_iam_policy(request, options = nil) ⇒ ::Google::Iam::V1::Policy #set_iam_policy(resource: nil, policy: nil) ⇒ ::Google::Iam::V1::Policy
Sets the access control policy on a Table or Backup resource. Replaces any existing policy.
1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1878 def set_iam_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V1::SetIamPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.set_iam_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "resource" => request.resource } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.set_iam_policy.timeout, metadata: , retry_policy: @config.rpcs.set_iam_policy.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :set_iam_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#snapshot_table(request, options = nil) ⇒ ::Gapic::Operation #snapshot_table(name: nil, cluster: nil, snapshot_id: nil, ttl: nil, description: nil) ⇒ ::Gapic::Operation
Creates a new snapshot in the specified cluster from the specified source table. The cluster and the table must be in the same instance.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 989 def snapshot_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::SnapshotTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.snapshot_table..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.snapshot_table.timeout, metadata: , retry_policy: @config.rpcs.snapshot_table.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :snapshot_table, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#test_iam_permissions(request, options = nil) ⇒ ::Google::Iam::V1::TestIamPermissionsResponse #test_iam_permissions(resource: nil, permissions: nil) ⇒ ::Google::Iam::V1::TestIamPermissionsResponse
Returns permissions that the caller has on the specified Table or Backup resource.
1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1950 def request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V1::TestIamPermissionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs...to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "resource" => request.resource } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs..timeout, metadata: , retry_policy: @config.rpcs..retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :test_iam_permissions, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_backup(request, options = nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup #update_backup(backup: nil, update_mask: nil) ⇒ ::Google::Cloud::Bigtable::Admin::V2::Backup
Updates a pending or completed Cloud Bigtable Backup.
1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 |
# File 'lib/google/cloud/bigtable/admin/v2/bigtable_table_admin/client.rb', line 1448 def update_backup request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::Admin::V2::UpdateBackupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_backup..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::Admin::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "backup.name" => request.backup.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_backup.timeout, metadata: , retry_policy: @config.rpcs.update_backup.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @bigtable_table_admin_stub.call_rpc :update_backup, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |