Class: Google::Cloud::Bigtable::Admin::V2::Cluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/admin/v2/instance.rb

Overview

A resizable group of nodes in a particular cloud location, capable of serving all Tables in the parent Instance.

Defined Under Namespace

Modules: State Classes: EncryptionConfig

Instance Attribute Summary collapse

Instance Attribute Details

#default_storage_type ⇒ ::Google::Cloud::Bigtable::Admin::V2::StorageType

Returns (CreationOnly) The type of storage used by this cluster to serve its parent instance's tables, unless explicitly overridden.

Returns:



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end

#encryption_config ⇒ ::Google::Cloud::Bigtable::Admin::V2::Cluster::EncryptionConfig

Returns Immutable. The encryption configuration for CMEK-protected clusters.

Returns:



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end

#location ⇒ ::String

Returns (CreationOnly) The location where this cluster's nodes and storage reside. For best performance, clients should be located as close as possible to this cluster. Currently only zones are supported, so values should be of the form projects/{project}/locations/{zone}.

Returns:

  • (::String) —

    (CreationOnly) The location where this cluster's nodes and storage reside. For best performance, clients should be located as close as possible to this cluster. Currently only zones are supported, so values should be of the form projects/{project}/locations/{zone}.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end

#name ⇒ ::String (readonly)

Returns The unique name of the cluster. Values are of the form projects/{project}/instances/{instance}/clusters/[a-z][-a-z0-9]*.

Returns:

  • (::String) —

    The unique name of the cluster. Values are of the form projects/{project}/instances/{instance}/clusters/[a-z][-a-z0-9]*.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end

#serve_nodes ⇒ ::Integer

Returns Required. The number of nodes allocated to this cluster. More nodes enable higher throughput and more consistent performance.

Returns:

  • (::Integer) —

    Required. The number of nodes allocated to this cluster. More nodes enable higher throughput and more consistent performance.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end

#state ⇒ ::Google::Cloud::Bigtable::Admin::V2::Cluster::State (readonly)

Returns The current state of the cluster.

Returns:



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 136

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected
  # cluster.
  # @!attribute [rw] kms_key_name
  #   @return [::String]
  #     Describes the Cloud KMS encryption key that will be used to protect the
  #     destination Bigtable cluster. The requirements for this key are:
  #      1) The Cloud Bigtable service account associated with the project that
  #      contains this cluster must be granted the
  #      `cloudkms.cryptoKeyEncrypterDecrypter` role on the CMEK key.
  #      2) Only regional keys can be used and the region of the CMEK key must
  #      match the region of the cluster.
  #     3) All clusters within an instance must use the same CMEK key.
  class EncryptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a cluster.
  module State
    # The state of the cluster could not be determined.
    STATE_NOT_KNOWN = 0

    # The cluster has been successfully created and is ready to serve requests.
    READY = 1

    # The cluster is currently being created, and may be destroyed
    # if the creation process encounters an error.
    # A cluster may not be able to serve requests while being created.
    CREATING = 2

    # The cluster is currently being resized, and may revert to its previous
    # node count if the process encounters an error.
    # A cluster is still capable of serving requests while being resized,
    # but may exhibit performance as if its number of allocated nodes is
    # between the starting and requested states.
    RESIZING = 3

    # The cluster has no backing nodes. The data (tables) still
    # exist, but no operations can be performed on the cluster.
    DISABLED = 4
  end
end