Class: Google::Cloud::Bigtable::Admin::V2::Cluster::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::Cluster::EncryptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/instance.rb
Overview
Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected cluster.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ ::String
Describes the Cloud KMS encryption key that will be used to protect the destination Bigtable cluster.
Instance Attribute Details
#kms_key_name ⇒ ::String
Returns Describes the Cloud KMS encryption key that will be used to protect the destination Bigtable cluster. The requirements for this key are:
- The Cloud Bigtable service account associated with the project that
contains this cluster must be granted the
cloudkms.cryptoKeyEncrypterDecrypterrole on the CMEK key. - Only regional keys can be used and the region of the CMEK key must match the region of the cluster.
- All clusters within an instance must use the same CMEK key.
152 153 154 155 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 152 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |