Class: Google::Cloud::Bigtable::Admin::V2::GcRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/admin/v2/table.rb

Overview

Rule for determining which cells to delete during garbage collection.

Defined Under Namespace

Classes: Intersection, Union

Instance Attribute Summary collapse

Instance Attribute Details

#intersection ⇒ ::Google::Cloud::Bigtable::Admin::V2::GcRule::Intersection



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 198

class GcRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A GcRule which deletes cells matching all of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Only delete cells which would be deleted by every element of `rules`.
  class Intersection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A GcRule which deletes cells matching any of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Delete cells which would be deleted by any element of `rules`.
  class Union
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#max_age ⇒ ::Google::Protobuf::Duration



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 198

class GcRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A GcRule which deletes cells matching all of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Only delete cells which would be deleted by every element of `rules`.
  class Intersection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A GcRule which deletes cells matching any of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Delete cells which would be deleted by any element of `rules`.
  class Union
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#max_num_versions ⇒ ::Integer



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 198

class GcRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A GcRule which deletes cells matching all of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Only delete cells which would be deleted by every element of `rules`.
  class Intersection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A GcRule which deletes cells matching any of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Delete cells which would be deleted by any element of `rules`.
  class Union
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#union ⇒ ::Google::Cloud::Bigtable::Admin::V2::GcRule::Union



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 198

class GcRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A GcRule which deletes cells matching all of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Only delete cells which would be deleted by every element of `rules`.
  class Intersection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A GcRule which deletes cells matching any of the given rules.
  # @!attribute [rw] rules
  #   @return [::Array<::Google::Cloud::Bigtable::Admin::V2::GcRule>]
  #     Delete cells which would be deleted by any element of `rules`.
  class Union
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end