Class: Google::Cloud::Bigtable::Admin::V2::Instance
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::Instance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/instance.rb
Overview
Defined Under Namespace
Modules: Edition, State, Type Classes: LabelsEntry, TagsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#edition ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::Edition
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies.
-
#name ⇒ ::String
The unique name of the instance.
-
#satisfies_pzi ⇒ ::Boolean
readonly
Output only.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::State
readonly
Output only.
-
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#type ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::Type
The type of the instance.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. A commit timestamp representing when this Instance was
created. For instances created before this field was added (August 2021),
this value is seconds: 0, nanos: 1.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#display_name ⇒ ::String
Returns Required. The descriptive name for this instance as it appears in UIs. Can be changed at any time, but should be kept globally unique to avoid confusion.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#edition ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::Edition
Returns Optional. The edition of the instance. See Edition for details.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies. They can be used to filter resources and aggregate metrics.
- Label keys must be between 1 and 63 characters long and must conform to
the regular expression:
[\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}. - Label values must be between 0 and 63 characters long and must conform to
the regular expression:
[\p{Ll}\p{Lo}\p{N}_-]{0,63}. - No more than 64 labels can be associated with a given resource.
- Keys and values must both be under 128 bytes.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#name ⇒ ::String
Returns The unique name of the instance. Values are of the form
projects/{project}/instances/[a-z][a-z0-9\\-]+[a-z0-9].
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#satisfies_pzi ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#state ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::State (readonly)
Returns Output only. The current state of the instance.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example:
- "123/environment": "production",
- "123/costCenter": "marketing"
Tags and Labels (above) are both used to bind metadata to resources, with different use-cases. See https://cloud.google.com/resource-manager/docs/tags/tags-overview for an in-depth overview on the difference between tags and labels.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |
#type ⇒ ::Google::Cloud::Bigtable::Admin::V2::Instance::Type
Returns The type of the instance. Defaults to PRODUCTION.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/bigtable/admin/v2/instance.rb', line 83 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of an instance. module State # The state of the instance could not be determined. STATE_NOT_KNOWN = 0 # The instance has been successfully created and can serve requests # to its tables. READY = 1 # The instance is currently being created, and may be destroyed # if the creation process encounters an error. CREATING = 2 end # The type of the instance. module Type # The type of the instance is unspecified. If set when creating an # instance, a `PRODUCTION` instance will be created. If set when updating # an instance, the type will be left unchanged. TYPE_UNSPECIFIED = 0 # An instance meant for production use. `serve_nodes` must be set # on the cluster. PRODUCTION = 1 # DEPRECATED: Prefer PRODUCTION for all use cases, as it no longer enforces # a higher minimum node count than DEVELOPMENT. DEVELOPMENT = 2 end # Possible editions of an instance. # # An edition is a specific tier of Cloud Bigtable. Each edition is tailored # to different customer needs. Higher tiers offer more features and better # performance. module Edition # The edition is unspecified. This is treated as `ENTERPRISE`. EDITION_UNSPECIFIED = 0 # The Enterprise edition. This is the default offering that is designed to # meet the needs of most enterprise workloads. ENTERPRISE = 1 # The Enterprise Plus edition. This is a premium tier that is designed for # demanding, multi-tenant workloads requiring the highest levels of # performance, scale, and global availability. # # The nodes in the Enterprise Plus tier come at a higher cost than the # Enterprise tier. Any Enterprise Plus features must be disabled before # downgrading to Enterprise. ENTERPRISE_PLUS = 2 end end |