Module: Google::Cloud::Bigtable::Admin::V2::Instance::Edition

Defined in:
proto_docs/google/bigtable/admin/v2/instance.rb

Overview

Possible editions of an instance.

An edition is a specific tier of Cloud Bigtable. Each edition is tailored to different customer needs. Higher tiers offer more features and better performance.

Constant Summary collapse

EDITION_UNSPECIFIED =

The edition is unspecified. This is treated as ENTERPRISE.

0
ENTERPRISE =

The Enterprise edition. This is the default offering that is designed to meet the needs of most enterprise workloads.

1
ENTERPRISE_PLUS =

The Enterprise Plus edition. This is a premium tier that is designed for demanding, multi-tenant workloads requiring the highest levels of performance, scale, and global availability.

The nodes in the Enterprise Plus tier come at a higher cost than the Enterprise tier. Any Enterprise Plus features must be disabled before downgrading to Enterprise.

2