Class: Google::Cloud::Bigtable::Admin::V2::ModifyColumnFamiliesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb

Overview

Defined Under Namespace

Classes: Modification

Instance Attribute Summary collapse

Instance Attribute Details

#modifications ⇒ ::Array<::Google::Cloud::Bigtable::Admin::V2::ModifyColumnFamiliesRequest::Modification>



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 268

class ModifyColumnFamiliesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A create, update, or delete of a particular column family.
  # @!attribute [rw] id
  #   @return [::String]
  #     The ID of the column family to be modified.
  # @!attribute [rw] create
  #   @return [::Google::Cloud::Bigtable::Admin::V2::ColumnFamily]
  #     Create a new column family with the specified schema, or fail if
  #     one already exists with the given ID.
  # @!attribute [rw] update
  #   @return [::Google::Cloud::Bigtable::Admin::V2::ColumnFamily]
  #     Update an existing column family to the specified schema, or fail
  #     if no column family exists with the given ID.
  # @!attribute [rw] drop
  #   @return [::Boolean]
  #     Drop (delete) the column family with the given ID, or fail if no such
  #     family exists.
  class Modification
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name ⇒ ::String



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 268

class ModifyColumnFamiliesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A create, update, or delete of a particular column family.
  # @!attribute [rw] id
  #   @return [::String]
  #     The ID of the column family to be modified.
  # @!attribute [rw] create
  #   @return [::Google::Cloud::Bigtable::Admin::V2::ColumnFamily]
  #     Create a new column family with the specified schema, or fail if
  #     one already exists with the given ID.
  # @!attribute [rw] update
  #   @return [::Google::Cloud::Bigtable::Admin::V2::ColumnFamily]
  #     Update an existing column family to the specified schema, or fail
  #     if no column family exists with the given ID.
  # @!attribute [rw] drop
  #   @return [::Boolean]
  #     Drop (delete) the column family with the given ID, or fail if no such
  #     family exists.
  class Modification
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end