Class: Google::Cloud::Bigtable::Admin::V2::ModifyColumnFamiliesRequest::Modification

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb

Overview

A create, update, or delete of a particular column family.

Instance Attribute Summary collapse

Instance Attribute Details

#create ⇒ ::Google::Cloud::Bigtable::Admin::V2::ColumnFamily

Returns Create a new column family with the specified schema, or fail if one already exists with the given ID.

Returns:



288
289
290
291
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 288

class Modification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#drop ⇒ ::Boolean

Returns Drop (delete) the column family with the given ID, or fail if no such family exists.

Returns:

  • (::Boolean) —

    Drop (delete) the column family with the given ID, or fail if no such family exists.



288
289
290
291
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 288

class Modification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id ⇒ ::String

Returns The ID of the column family to be modified.

Returns:

  • (::String) —

    The ID of the column family to be modified.



288
289
290
291
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 288

class Modification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update ⇒ ::Google::Cloud::Bigtable::Admin::V2::ColumnFamily

Returns Update an existing column family to the specified schema, or fail if no column family exists with the given ID.

Returns:



288
289
290
291
# File 'proto_docs/google/bigtable/admin/v2/bigtable_table_admin.rb', line 288

class Modification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end