Class: Google::Cloud::Bigtable::Admin::V2::Table::AutomatedBackupPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/admin/v2/table.rb

Overview

Defines an automated backup policy for a table

Instance Attribute Summary collapse

Instance Attribute Details

#frequency::Google::Protobuf::Duration

Returns How frequently automated backups should occur. The only supported value at this time is 24 hours. An undefined frequency is treated as 24 hours.

Returns:

  • (::Google::Protobuf::Duration)

    How frequently automated backups should occur. The only supported value at this time is 24 hours. An undefined frequency is treated as 24 hours.



230
231
232
233
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 230

class AutomatedBackupPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#locations::Array<::String>

Returns Optional. A list of Cloud Bigtable zones where automated backups are allowed to be created. If empty, automated backups will be created in all zones of the instance. Locations are in the format projects/{project}/locations/{zone}. This field can only set for tables in Enterprise Plus instances.

Returns:

  • (::Array<::String>)

    Optional. A list of Cloud Bigtable zones where automated backups are allowed to be created. If empty, automated backups will be created in all zones of the instance. Locations are in the format projects/{project}/locations/{zone}. This field can only set for tables in Enterprise Plus instances.



230
231
232
233
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 230

class AutomatedBackupPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#retention_period::Google::Protobuf::Duration

Returns Required. How long the automated backups should be retained. Values must be at least 3 days and at most 90 days.

Returns:

  • (::Google::Protobuf::Duration)

    Required. How long the automated backups should be retained. Values must be at least 3 days and at most 90 days.



230
231
232
233
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 230

class AutomatedBackupPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end