Class: Google::Cloud::Bigtable::Admin::V2::TieredStorageConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::TieredStorageConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/table.rb
Overview
Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage).
Instance Attribute Summary collapse
-
#infrequent_access ⇒ ::Google::Cloud::Bigtable::Admin::V2::TieredStorageRule
Rule to specify what data is stored in the infrequent access(IA) tier.
Instance Attribute Details
#infrequent_access ⇒ ::Google::Cloud::Bigtable::Admin::V2::TieredStorageRule
Returns Rule to specify what data is stored in the infrequent access(IA) tier. The IA tier allows storing more data per node with reduced performance.
664 665 666 667 |
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 664 class TieredStorageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |