Class: Google::Cloud::Bigtable::Admin::V2::AuthorizedView::SubsetView
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::AuthorizedView::SubsetView
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/table.rb
Overview
Defines a simple AuthorizedView that is a subset of the underlying Table.
Defined Under Namespace
Classes: FamilySubsetsEntry
Instance Attribute Summary collapse
-
#family_subsets ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::Admin::V2::AuthorizedView::FamilySubsets}
Map from column family name to the columns in this family to be included in the AuthorizedView.
-
#row_prefixes ⇒ ::Array<::String>
Row prefixes to be included in the AuthorizedView.
Instance Attribute Details
#family_subsets ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::Admin::V2::AuthorizedView::FamilySubsets}
Returns Map from column family name to the columns in this family to be included in the AuthorizedView.
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 330 class SubsetView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::Admin::V2::AuthorizedView::FamilySubsets] class FamilySubsetsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#row_prefixes ⇒ ::Array<::String>
Returns Row prefixes to be included in the AuthorizedView. To provide access to all rows, include the empty string as a prefix ("").
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 330 class SubsetView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::Admin::V2::AuthorizedView::FamilySubsets] class FamilySubsetsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |