Class: Google::Cloud::Bigtable::Admin::V2::TieredStorageRule
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::Admin::V2::TieredStorageRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/admin/v2/table.rb
Overview
Rule to specify what data is stored in a storage tier.
Instance Attribute Summary collapse
-
#include_if_older_than ⇒ ::Google::Protobuf::Duration
Include cells older than the given age.
Instance Attribute Details
#include_if_older_than ⇒ ::Google::Protobuf::Duration
Returns Include cells older than the given age. For the infrequent access tier, this value must be at least 30 days.
674 675 676 677 |
# File 'proto_docs/google/bigtable/admin/v2/table.rb', line 674 class TieredStorageRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |